==> ecs_1.4.0.orig.tar.gz: ecs-1.4.0/inc/pre-post/ecs_med.h <==
#ifndef _ECS_MED_H_
#define _ECS_MED_H_

/*============================================================================
 *  Dfinitions de macros et constantes
 *   servant au traitement de maillages au format MED
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2007 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                                 Visibilit
 *============================================================================*/

#include "ecs_config.h"

#if defined(HAVE_MED)


/*----------------------------------------------------------------------------
 *  Fichiers `include' librairie standard C
 *----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage global "Utilitaire"
 *----------------------------------------------------------------------------*/

#include "ecs_def.h"


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage global "MED"
 *----------------------------------------------------------------------------*/

#include "ecs_med_publ.h"


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  des paquetages visibles
 *----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage courant
 *----------------------------------------------------------------------------*/


/*============================================================================
 *                       Dfinition de macros
 *============================================================================*/


/*============================================================================
 * Fonctions publiques
 *============================================================================*/


/*----------------------------------------------------------------------------
 * Fonction de rcupration d'informations sur les librairies associes
 * (pour les librairies charges dynamiquement dont la version peut tre
 * modifie au lancement).
 *----------------------------------------------------------------------------*/

void ecs_med__version_shlib
(
 void
) ;

#endif /* HAVE_MED */

#endif /* _ECS_MED_H_ */

==> ecs_2.0.0.rc1.orig.tar.gz: ecs-2.0.0-rc1/inc/pre-post/ecs_med.h <==
#ifndef _ECS_MED_H_
#define _ECS_MED_H_

/*============================================================================
 *  Définitions de macros et constantes
 *   servant au traitement de maillages au format MED
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2009 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                                 Visibilité
 *============================================================================*/

#include "ecs_config.h"

#if defined(HAVE_MED)


/*----------------------------------------------------------------------------
 *  Fichiers `include' librairie standard C
 *----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage global "Utilitaire"
 *----------------------------------------------------------------------------*/

#include "ecs_def.h"


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  des paquetages visibles
 *----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage courant
 *----------------------------------------------------------------------------*/


/*============================================================================
 *                      Définitions de variables globales
 *============================================================================*/

/* Variables de définition de la version des librairies */

extern int  ecs_glob_med_ver_maj;
extern int  ecs_glob_med_ver_min;
extern int  ecs_glob_med_ver_rel;
extern int  ecs_glob_hdf5_ver_maj;
extern int  ecs_glob_hdf5_ver_min;
extern int  ecs_glob_hdf5_ver_rel;


/*============================================================================
 *                          Définitions de types
 *============================================================================*/

/* Structure définissant un cas MED */

typedef struct _ecs_med_t ecs_med_t;


/*============================================================================
 *                       Définition de macros
 *============================================================================*/


/*============================================================================
 * Fonctions publiques
 *============================================================================*/

/*----------------------------------------------------------------------------
 * Fonction de récupération d'informations sur les librairies associées
 * (pour les librairies chargées dynamiquement dont la version peut être
 * modifiée au lancement).
 *----------------------------------------------------------------------------*/

void
ecs_med__version_shlib(void);

#endif /* HAVE_MED */

#endif /* _ECS_MED_H_ */
